summaryrefslogtreecommitdiffstats
path: root/src/prefAuthor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/prefAuthor.cpp')
-rw-r--r--src/prefAuthor.cpp76
1 files changed, 38 insertions, 38 deletions
diff --git a/src/prefAuthor.cpp b/src/prefAuthor.cpp
index f43d619..98d3d36 100644
--- a/src/prefAuthor.cpp
+++ b/src/prefAuthor.cpp
@@ -9,75 +9,75 @@
#include "prefAuthor.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qgroupbox.h>
-#include <qcombobox.h>
-#include <qlabel.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqgroupbox.h>
+#include <tqcombobox.h>
+#include <tqlabel.h>
#include <knuminput.h>
#include <kpushbutton.h>
#include <kcolorbutton.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "knuminput.h"
#include "kpushbutton.h"
#include "kcolorbutton.h"
/*
* Constructs a prefAuthor as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-prefAuthor::prefAuthor( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+prefAuthor::prefAuthor( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "prefAuthor" );
- prefAuthorLayout = new QGridLayout( this, 1, 1, 11, 6, "prefAuthorLayout");
+ prefAuthorLayout = new TQGridLayout( this, 1, 1, 11, 6, "prefAuthorLayout");
- groupBox1 = new QGroupBox( this, "groupBox1" );
+ groupBox1 = new TQGroupBox( this, "groupBox1" );
groupBox1->setColumnLayout(0, Qt::Vertical );
- groupBox1->layout()->setSpacing( 6 );
- groupBox1->layout()->setMargin( 11 );
- groupBox1Layout = new QGridLayout( groupBox1->layout() );
- groupBox1Layout->setAlignment( Qt::AlignTop );
+ groupBox1->tqlayout()->setSpacing( 6 );
+ groupBox1->tqlayout()->setMargin( 11 );
+ groupBox1Layout = new TQGridLayout( groupBox1->tqlayout() );
+ groupBox1Layout->tqsetAlignment( TQt::AlignTop );
- cbAudioFormat = new QComboBox( FALSE, groupBox1, "cbAudioFormat" );
+ cbAudioFormat = new TQComboBox( FALSE, groupBox1, "cbAudioFormat" );
groupBox1Layout->addWidget( cbAudioFormat, 0, 1 );
- cbAudioBitrate = new QComboBox( FALSE, groupBox1, "cbAudioBitrate" );
+ cbAudioBitrate = new TQComboBox( FALSE, groupBox1, "cbAudioBitrate" );
groupBox1Layout->addWidget( cbAudioBitrate, 1, 1 );
- textLabel1 = new QLabel( groupBox1, "textLabel1" );
+ textLabel1 = new TQLabel( groupBox1, "textLabel1" );
groupBox1Layout->addWidget( textLabel1, 0, 0 );
- textLabel2 = new QLabel( groupBox1, "textLabel2" );
+ textLabel2 = new TQLabel( groupBox1, "textLabel2" );
groupBox1Layout->addWidget( textLabel2, 1, 0 );
- spacer1 = new QSpacerItem( 151, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer1 = new TQSpacerItem( 151, 21, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
groupBox1Layout->addMultiCell( spacer1, 0, 1, 2, 2 );
prefAuthorLayout->addWidget( groupBox1, 0, 0 );
- spacer3 = new QSpacerItem( 20, 60, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer3 = new TQSpacerItem( 20, 60, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
prefAuthorLayout->addItem( spacer3, 2, 0 );
- groupBox2 = new QGroupBox( this, "groupBox2" );
+ groupBox2 = new TQGroupBox( this, "groupBox2" );
groupBox2->setColumnLayout(0, Qt::Vertical );
- groupBox2->layout()->setSpacing( 6 );
- groupBox2->layout()->setMargin( 11 );
- groupBox2Layout = new QGridLayout( groupBox2->layout() );
- groupBox2Layout->setAlignment( Qt::AlignTop );
+ groupBox2->tqlayout()->setSpacing( 6 );
+ groupBox2->tqlayout()->setMargin( 11 );
+ groupBox2Layout = new TQGridLayout( groupBox2->tqlayout() );
+ groupBox2Layout->tqsetAlignment( TQt::AlignTop );
- textLabel3 = new QLabel( groupBox2, "textLabel3" );
+ textLabel3 = new TQLabel( groupBox2, "textLabel3" );
groupBox2Layout->addWidget( textLabel3, 0, 0 );
- spacer2 = new QSpacerItem( 121, 31, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer2 = new TQSpacerItem( 121, 31, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
groupBox2Layout->addItem( spacer2, 0, 2 );
- textLabel5 = new QLabel( groupBox2, "textLabel5" );
+ textLabel5 = new TQLabel( groupBox2, "textLabel5" );
groupBox2Layout->addWidget( textLabel5, 1, 0 );
@@ -97,7 +97,7 @@ prefAuthor::prefAuthor( QWidget* parent, const char* name, WFlags fl )
groupBox2Layout->addWidget( bButtonFont, 4, 1 );
- textLabel6 = new QLabel( groupBox2, "textLabel6" );
+ textLabel6 = new TQLabel( groupBox2, "textLabel6" );
groupBox2Layout->addWidget( textLabel6, 2, 0 );
@@ -105,7 +105,7 @@ prefAuthor::prefAuthor( QWidget* parent, const char* name, WFlags fl )
groupBox2Layout->addWidget( cbHiliteColor, 2, 1 );
- textLabel6_2 = new QLabel( groupBox2, "textLabel6_2" );
+ textLabel6_2 = new TQLabel( groupBox2, "textLabel6_2" );
groupBox2Layout->addWidget( textLabel6_2, 3, 0 );
@@ -115,11 +115,11 @@ prefAuthor::prefAuthor( QWidget* parent, const char* name, WFlags fl )
prefAuthorLayout->addWidget( groupBox2, 1, 0 );
languageChange();
- resize( QSize(600, 480).expandedTo(minimumSizeHint()) );
+ resize( TQSize(600, 480).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( bButtonFont, SIGNAL( clicked() ), this, SLOT( bButtonFontClicked() ) );
+ connect( bButtonFont, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bButtonFontClicked() ) );
}
/*
@@ -127,7 +127,7 @@ prefAuthor::prefAuthor( QWidget* parent, const char* name, WFlags fl )
*/
prefAuthor::~prefAuthor()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -152,9 +152,9 @@ void prefAuthor::languageChange()
textLabel5->setText( tr2i18n( "Height" ) );
bButtonFont->setText( tr2i18n( "Font" ) );
textLabel6->setText( tr2i18n( "Hilite color" ) );
- cbHiliteColor->setText( QString::null );
+ cbHiliteColor->setText( TQString() );
textLabel6_2->setText( tr2i18n( "Text color" ) );
- cbTextColor->setText( QString::null );
+ cbTextColor->setText( TQString() );
}
void prefAuthor::bButtonFontClicked()
@@ -9,75 +9,75 @@
#include "kcolorbutton.h"
/*
- * Constructs a prefAuthor as a child of 'parent', with the
+ * Constructs a prefAuthor as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -127,7 +127,7 @@ prefAuthor::prefAuthor( QWidget* parent, const char* name, WFlags fl )
prefAuthor::~prefAuthor()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*